==> kubernetes-model-policy-6.4.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/EvictionFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.DeleteOptions;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EvictionFluent<A extends EvictionFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public DeleteOptions getDeleteOptions();
  public A withDeleteOptions(DeleteOptions deleteOptions);
  public Boolean hasDeleteOptions();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public EvictionFluent.MetadataNested<A> withNewMetadata();
  public EvictionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public EvictionFluent.MetadataNested<A> editMetadata();
  public EvictionFluent.MetadataNested<A> editOrNewMetadata();
  public EvictionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<EvictionFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> kubernetes-model-policy-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/EvictionFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.DeleteOptions;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EvictionFluent<A extends EvictionFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public DeleteOptions getDeleteOptions();
  public A withDeleteOptions(DeleteOptions deleteOptions);
  public Boolean hasDeleteOptions();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public EvictionFluent.MetadataNested<A> withNewMetadata();
  public EvictionFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public EvictionFluent.MetadataNested<A> editMetadata();
  public EvictionFluent.MetadataNested<A> editOrNewMetadata();
  public EvictionFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<EvictionFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
